TODO List
=========


.. todolist::



Modify so that you can build using a zip file. https://stackoverflow.com/questions/66181180/perform-an-os-walk-through-a-zip-compressed-file-using-the-zipfile-module

